@@ -30,7 +30,7 @@ import java.util.Properties;
 /**
  * Specifies the parameters used to control a Maven invocation.
  * 
- * @version $Id: DefaultInvocationRequest.java 807415 2009-08-24 22:32:16Z olamy $
+ * @version $Id: DefaultInvocationRequest.java 1392618 2012-10-01 21:20:53Z rfscholte $
  */
 public class DefaultInvocationRequest
     implements InvocationRequest
@@ -44,7 +44,7 @@ public class DefaultInvocationRequest
 
     private String failureBehavior = REACTOR_FAIL_FAST;
 
-    private List goals;
+    private List<String> goals;
 
     private InputStream inputStream;
 
@@ -70,17 +70,21 @@ public class DefaultInvocationRequest
 
     private File userSettings;
 
+    private File globalSettings;
+    
+    private File toolchains;
+
     private String globalChecksumPolicy;
 
     private String pomFilename;
 
     private File javaHome;
 
-    private List profiles;
+    private List<String> profiles;
 
     private boolean nonPluginUpdates;
 
-    private Map shellEnvironments;
+    private Map<String, String> shellEnvironments;
 
     private String mavenOpts;
     
@@ -88,8 +92,18 @@ public class DefaultInvocationRequest
 
     private String[] activatedReactorIncludes, activatedReactorExcludes;
     
+    private List<String> projects;
+
+    private boolean alsoMake;
+
+    private boolean alsoMakeDependents;
+
+    private String resumeFrom;
+
     private boolean showVersion;
 
+    private String threads;
+
     public InvocationRequest activateReactor( String[] includes, String[] excludes )
     {
         activatedReactor = true;
@@ -118,7 +132,7 @@ public class DefaultInvocationRequest
         return failureBehavior;
     }
 
-    public List getGoals()
+    public List<String> getGoals()
     {
         return goals;
     }
@@ -208,7 +222,7 @@ public class DefaultInvocationRequest
         return this;
     }
 
-    public InvocationRequest setGoals( List goals )
+    public InvocationRequest setGoals( List<String> goals )
     {
         this.goals = goals;
         return this;
@@ -294,13 +308,35 @@ public class DefaultInvocationRequest
     {
         return userSettings;
     }
-
+    
     public InvocationRequest setUserSettingsFile( File userSettings )
     {
         this.userSettings = userSettings;
         return this;
     }
 
+    public File getGlobalSettingsFile()
+    {
+        return globalSettings;
+    }
+
+    public InvocationRequest setGlobalSettingsFile( File globalSettings )
+    {
+        this.globalSettings = globalSettings;
+        return this;
+    }
+
+    public File getToolchainsFile()
+    {
+        return toolchains;
+    }
+    
+    public InvocationRequest setToolchainsFile( File toolchains )
+    {
+        this.toolchains = toolchains;
+        return this;
+    }
+    
     public String getGlobalChecksumPolicy()
     {
         return globalChecksumPolicy;
@@ -323,12 +359,12 @@ public class DefaultInvocationRequest
         return this;
     }
 
-    public List getProfiles()
+    public List<String> getProfiles()
     {
         return profiles;
     }
 
-    public InvocationRequest setProfiles( List profiles )
+    public InvocationRequest setProfiles( List<String> profiles )
     {
         this.profiles = profiles;
         return this;
@@ -349,15 +385,15 @@ public class DefaultInvocationRequest
     {
         if ( this.shellEnvironmentInherited )
         {
-            this.shellEnvironments = new HashMap();
+            this.shellEnvironments = new HashMap<String, String>();
         }
         this.shellEnvironments.put( name, value );
         return this;
     }
 
-    public Map getShellEnvironments()
+    public Map<String, String> getShellEnvironments()
     {
-        return shellEnvironments == null ? Collections.EMPTY_MAP : shellEnvironments;
+        return shellEnvironments == null ? Collections.<String, String>emptyMap(): shellEnvironments;
     }
 
     public String getMavenOpts()
@@ -402,5 +438,90 @@ public class DefaultInvocationRequest
         this.showVersion = showVersion;
         return this;
     }
+    
+    /**
+     * {@inheritDoc}
+     */
+    public String getThreads()
+    {
+        return threads;
+    }
+    
+    /**
+     * {@inheritDoc}
+     */
+    public InvocationRequest setThreads( String threads )
+    {
+        this.threads = threads;
+        return this;
+    }
 
+    /**
+     * {@inheritDoc}
+     */
+    public List<String> getProjects()
+    {
+        return projects;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public InvocationRequest setProjects( List<String> projects )
+    {
+        this.projects = projects;
+        return this;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public boolean isAlsoMake()
+    {
+        return alsoMake;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public InvocationRequest setAlsoMake( boolean alsoMake )
+    {
+        this.alsoMake = alsoMake;
+        return this;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public boolean isAlsoMakeDependents()
+    {
+        return alsoMakeDependents;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public InvocationRequest setAlsoMakeDependents( boolean alsoMakeDependents )
+    {
+        this.alsoMakeDependents = alsoMakeDependents;
+        return this;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public String getResumeFrom()
+    {
+        return resumeFrom;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public InvocationRequest setResumeFrom( String resumeFrom )
+    {
+        this.resumeFrom = resumeFrom;
+        return this;
+    }
+    
 }
