@@ -28,7 +28,7 @@ import java.util.Properties;
 /**
  * Specifies the parameters used to control a Maven invocation.
  * 
- * @version $Id: InvocationRequest.java 807415 2009-08-24 22:32:16Z olamy $
+ * @version $Id: InvocationRequest.java 1395369 2012-10-07 19:14:10Z rfscholte $
  */
 public interface InvocationRequest
 {
@@ -84,6 +84,38 @@ public interface InvocationRequest
      */
     public String[] getActivatedReactorExcludes();
 
+    /**
+     * A list of specified reactor projects to build instead of all projects. 
+     * A project can be specified by [groupId]:artifactId or by its relative path.
+     * 
+     * @return the list of projects to add to reactor build, otherwise {@code null}
+     * @since 2.1
+     */
+    public List<String> getProjects();
+
+    /**
+     * Get the value of the {@code also-make} argument.
+     * 
+     * @return {@code true} if the argument {@code also-make} was specified, otherwise {@code false}
+     * @since 2.1
+     */
+    boolean isAlsoMake();
+
+    /**
+     * Get the value of the {@code also-make-dependents}
+     * 
+     * @return {@code true} if the argument {@code also-make-dependents} was specified, otherwise {@code false}
+     * @since 2.1
+     */
+    boolean isAlsoMakeDependents();
+
+    /**
+     * Get the value of {@code resume-from}
+     * 
+     * @return specified reactor project to resume from
+     * @since 2.1
+     */
+    String getResumeFrom();
 
     /**
      * Gets the debug mode of the Maven invocation. By default, Maven is executed in normal mode.
@@ -211,7 +243,7 @@ public interface InvocationRequest
      * 
      * @return The goals for the Maven invocation or <code>null</code> if not set.
      */
-    List getGoals();
+    List<String> getGoals();
 
     /**
      * Gets the path to the user settings for the Maven invocation.
@@ -221,6 +253,23 @@ public interface InvocationRequest
      */
     File getUserSettingsFile();
 
+    /**
+     * Gets the path to the global settings for the Maven invocation.
+     * 
+     * @return The path to the global settings for the Maven invocation or <code>null</code> to load the global settings
+     *         from the default location.
+     * @since 2.1
+     */
+    File getGlobalSettingsFile();
+    
+    /**
+     * Gets the path to the custom toolchains file
+     * 
+     * @return The path to the custom toolchains file or <code>null</code> to load the toolchains from the default location
+     * @since 2.1
+     */
+    File getToolchainsFile();
+
     /**
      * Gets the checksum mode of the Maven invocation.
      * 
@@ -233,14 +282,14 @@ public interface InvocationRequest
      * 
      * @return The profiles for the Maven invocation or <code>null</code> if not set.
      */
-    List getProfiles();
+    List<String> getProfiles();
 
     /**
      * Gets the environment variables for the Maven invocation.
      * 
      * @return The environment variables for the Maven invocation or <code>null</code> if not set.
      */
-    Map getShellEnvironments();
+    Map<String, String> getShellEnvironments();
 
     /**
      * Gets the value of the <code>MAVEN_OPTS</code> environment variable.
@@ -256,6 +305,14 @@ public interface InvocationRequest
      */
     boolean isShowVersion();
 
+    /**
+     * Get the value of the {@code threads} argument.
+     * 
+     * @return the value of the {@code threads} argument or {@code null} if not set
+     * @since 2.1
+     */
+    String getThreads();
+
     // ----------------------------------------------------------------------
     // Reactor Failure Mode
     // ----------------------------------------------------------------------
@@ -295,6 +352,7 @@ public interface InvocationRequest
 
     /**
      * Sets the interaction mode of the Maven invocation.
+     * <em>Inverse</em> equivalent of {@code -B} and {@code --batch-mode} 
      * 
      * @param interactive <code>true</code> if Maven should be executed in interactive mode, <code>false</code> if
      *            the batch mode is used.
@@ -304,6 +362,7 @@ public interface InvocationRequest
 
     /**
      * Sets the network mode of the Maven invocation.
+     * Equivalent of {@code -o} and {@code --offline}
      * 
      * @param offline <code>true</code> if Maven should be executed in offline mode, <code>false</code> if the
      *            online mode is used.
@@ -313,6 +372,7 @@ public interface InvocationRequest
 
     /**
      * Sets the debug mode of the Maven invocation.
+     * Equivalent of {@code -X} and {@code --debug}
      * 
      * @param debug <code>true</code> if Maven should be executed in debug mode, <code>false</code> if the normal
      *            mode should be used.
@@ -322,6 +382,7 @@ public interface InvocationRequest
 
     /**
      * Sets the exception output mode of the Maven invocation.
+     * Equivalent of {@code -e} and {@code --errors}
      * 
      * @param showErrors <code>true</code> if Maven should print stack traces, <code>false</code> otherwise.
      * @return This invocation request.
@@ -330,6 +391,7 @@ public interface InvocationRequest
 
     /**
      * Specifies whether Maven should enforce an update check for plugins and snapshots.
+     * Equivalent of {@code -U} and {@code --update-snapshots}
      * 
      * @param updateSnapshots <code>true</code> if plugins and snapshots should be updated, <code>false</code>
      *            otherwise.
@@ -339,6 +401,7 @@ public interface InvocationRequest
 
     /**
      * Sets the failure mode of the Maven invocation.
+     * Equivalent of {@code -ff} and {@code --fail-fast}, {@code -fae} and {@code --fail-at-end}, {@code -fn} and {@code --fail-never} 
      * 
      * @param failureBehavior The failure mode, must be one of {@link #REACTOR_FAIL_FAST}, {@link #REACTOR_FAIL_AT_END}
      *            and {@link #REACTOR_FAIL_NEVER}.
@@ -440,15 +503,16 @@ public interface InvocationRequest
      * @param goals The goals for the Maven invocation, may be <code>null</code> to execute the POMs default goal.
      * @return This invocation request.
      */
-    InvocationRequest setGoals( List goals );
+    InvocationRequest setGoals( List<String> goals );
 
     /**
      * Sets the profiles for the Maven invocation.
+     * Equivalent of {@code -P} and {@code --active-profiles}
      * 
      * @param profiles The profiles for the Maven invocation, may be <code>null</code> to use the default profiles.
      * @return This invocation request.
      */
-    InvocationRequest setProfiles( List profiles );
+    InvocationRequest setProfiles( List<String> profiles );
 
     /**
      * Specifies whether the environment variables of the current process should be propagated to the Maven invocation.
@@ -461,15 +525,40 @@ public interface InvocationRequest
 
     /**
      * Sets the path to the user settings for the Maven invocation.
-     * 
+     * Equivalent of {@code -s} and {@code --settings}
+     *  
      * @param userSettings The path to the user settings for the Maven invocation, may be <code>null</code> to load
      *            the user settings from the default location.
      * @return This invocation request.
      */
     InvocationRequest setUserSettingsFile( File userSettings );
 
+    /**
+     * Sets the path to the global settings for the Maven invocation.
+     * Equivalent of {@code -gs} and {@code --global-settings}
+     * 
+     * @param globalSettings The path to the global settings for the Maven invocation, may be <code>null</code> to load
+     *            the global settings from the default location.
+     * @return This invocation request.
+     * @since 2.1
+     */
+    InvocationRequest setGlobalSettingsFile( File globalSettings );
+
+    /**
+     * Sets the alternate path for the user toolchains file
+     * Equivalent of {@code -t} or {@code --toolchains}
+     * <p>
+     * <strong>note: </strong>available since Maven3
+     * </p>
+     * 
+     * @param toolchains the alternate path for the user toolchains file
+     * @return This invocation request
+     * @since 2.1
+     */
+    InvocationRequest setToolchainsFile( File toolchains );
     /**
      * Sets the checksum mode of the Maven invocation.
+     * Equivalent of {@code -c} or {@code --lax-checksums}, {@code -C} or {@code --strict-checksums} 
      * 
      * @param globalChecksumPolicy The checksum mode, must be one of {@link #CHECKSUM_POLICY_WARN} and
      *            {@link #CHECKSUM_POLICY_FAIL}.
@@ -479,7 +568,10 @@ public interface InvocationRequest
 
     /**
      * Specifies whether Maven should check for plugin updates.
-     * 
+     * <p>
+     * Equivalent of {@code -npu} or {@code --no-plugin-updates}<br/> 
+     * <strong>note: </strong>Ineffective with Maven3, only kept for backward compatibility
+     * </p>
      * @param nonPluginUpdates <code>true</code> if plugin updates should be suppressed, <code>false</code>
      *            otherwise.
      * @return This invocation request.
@@ -488,6 +580,7 @@ public interface InvocationRequest
 
     /**
      * Sets the recursion behavior of a reactor invocation.
+     * <em>Inverse</em> equivalent of {@code -N} and {@code --non-recursive}
      * 
      * @param recursive <code>true</code> if sub modules should be build, <code>false</code> otherwise.
      * @return This invocation request.
@@ -513,11 +606,66 @@ public interface InvocationRequest
     InvocationRequest setMavenOpts( String mavenOpts );
     
     /**
-     * enable displaying version without stopping the build (-V cli option)
+     * enable displaying version without stopping the build
+     * Equivalent of {@code -V} or {@code --show-version}
+     * 
      * @param showVersion enable displaying version 
-     * @since 2.0.11
      * @return This invocation request.
+     * @since 2.0.11
      */
     InvocationRequest setShowVersion( boolean showVersion );
 
+    /**
+     * Thread count, for instance 2.0C where C is core multiplied
+     * Equivalent of {@code -T} or {@code --threads}
+     * <p>
+     * <strong>note: </strong>available since Maven3
+     * </p>
+     * 
+     * @param threads the threadcount
+     * @return This invocation request.
+     * @since 2.1
+     */
+    InvocationRequest setThreads( String threads );
+
+    /**
+     * Sets the reactor project list.
+     * Equivalent of {@code -P} or {@code --projects}
+     * 
+     * @param projects the reactor project list 
+     * @return This invocation request.
+     * @since 2.1
+     */
+    InvocationRequest setProjects( List<String> projects );
+
+    /**
+     * Enable the 'also make' mode.
+     * Equivalent of {@code -am} or {@code --also-make}
+     * 
+     * @param alsoMake enable 'also make' mode 
+     * @return This invocation request.
+     * @since 2.1
+     */
+    InvocationRequest setAlsoMake( boolean alsoMake );
+
+	/**
+     * Enable the 'also make dependents' mode.
+     * Equivalent of {@code -amd} or {@code --also-make-dependents}
+     * 
+     * @param alsoMake enable 'also make' mode 
+     * @return This invocation request.
+     * @since 2.1
+     */
+    InvocationRequest setAlsoMakeDependents( boolean alsoMakeDependents );
+
+    /**
+     * Resume reactor from specified project.
+     * Equivalent of {@code -rf} or {@code --resume-from}
+     * 
+     * @param resumeFrom set the project to resume from
+     * @return This invocation request
+     * @since 2.1
+     */
+    InvocationRequest setResumeFrom( String resumeFrom );
+    
 }
