@@ -19,12 +19,6 @@ package org.apache.maven.shared.invoker;
  * under the License.
  */
 
-import junit.framework.TestCase;
-import org.codehaus.plexus.util.FileUtils;
-import org.codehaus.plexus.util.IOUtil;
-import org.codehaus.plexus.util.Os;
-import org.codehaus.plexus.util.cli.Commandline;
-
 import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
@@ -32,16 +26,22 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 
+import junit.framework.TestCase;
+
+import org.codehaus.plexus.util.Os;
+import org.codehaus.plexus.util.cli.Commandline;
+import org.codehaus.plexus.util.FileUtils;
+import org.codehaus.plexus.util.IOUtil;
+
 public class MavenCommandLineBuilderTest
     extends TestCase
 {
 
-    private List toDelete = new ArrayList();
+    private List<File> toDelete = new ArrayList<File>();
 
     private Properties sysProps;
 
@@ -127,7 +127,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setEnvironmentPaths( newRequest(), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "maven.repo.local=" + lrd.getPath() }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "maven.repo.local=" + lrd.getPath() );
     }
 
     public void testShouldSetLocalRepoLocationFromRequest()
@@ -148,7 +148,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setEnvironmentPaths( newRequest().setLocalRepositoryDirectory( lrd ), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "maven.repo.local=" + lrd.getPath() }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "maven.repo.local=" + lrd.getPath() );
     }
 
     public void testRequestProvidedLocalRepoLocationShouldOverrideGlobal()
@@ -174,7 +174,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setEnvironmentPaths( newRequest().setLocalRepositoryDirectory( lrd ), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "maven.repo.local=" + lrd.getPath() }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "maven.repo.local=" + lrd.getPath() );
     }
 
     public void testShouldSetWorkingDirectoryGlobally()
@@ -366,7 +366,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setInteractive( false ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-B" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-B" ) );
     }
 
     public void testShouldSetOfflineFlagFromRequest()
@@ -378,7 +378,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setOffline( true ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-o" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-o" ) );
     }
 
     public void testShouldSetUpdateSnapshotsFlagFromRequest()
@@ -390,7 +390,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setUpdateSnapshots( true ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-U" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-U" ) );
     }
 
     public void testShouldSetDebugFlagFromRequest()
@@ -402,7 +402,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setDebug( true ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-X" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-X" ) );
     }
 
     public void testShouldSetErrorFlagFromRequest()
@@ -414,7 +414,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setShowErrors( true ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-e" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-e" ) );
     }
 
     public void testDebugOptionShouldMaskShowErrorsOption()
@@ -426,8 +426,8 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setDebug( true ).setShowErrors( true ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-X" ), cli );
-        assertArgumentsNotPresent( Collections.singleton( "-e" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-X" ) );
+        assertArgumentsNotPresent( cli, Collections.singleton( "-e" ) );
     }
     
     public void testActivateReactor()
@@ -439,9 +439,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setReactorBehavior( newRequest().activateReactor( null, null ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-r" ), cli );
-
-        
+        assertArgumentsPresent( cli, Collections.singleton( "-r" ) );
     }
     
     public void testActivateReactorIncludesExcludes()
@@ -456,16 +454,87 @@ public class MavenCommandLineBuilderTest
         
         tcb.setReactorBehavior( newRequest().activateReactor( includes, excludes ), cli );
         
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-r" );
         args.add( "-D" );
         args.add( "maven.reactor.includes=foo,bar" );
         args.add( "maven.reactor.excludes=baz,quz" );
 
-        assertArgumentsPresent( args, cli );
-
-
+        assertArgumentsPresent( cli, args );
+    }
+    
+    public void testAlsoMake()
+    {
+        logTestStart();
         
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setAlsoMake( true ), cli );
+
+        //-am is only useful with -pl
+        assertArgumentsNotPresent( cli, Collections.singleton( "-am" ) );
+    }
+
+    public void testProjectsAndAlsoMake()
+    {
+        logTestStart();
+        
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setProjects( Collections.singletonList( "proj1" ) ).setAlsoMake( true ), cli );
+
+        assertArgumentsPresentInOrder( cli, "-pl", "proj1", "-am" );
+    }
+
+    public void testAlsoMakeDependents()
+    {
+        logTestStart();
+        
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setAlsoMakeDependents( true ), cli );
+
+        //-amd is only useful with -pl
+        assertArgumentsNotPresent( cli, Collections.singleton( "-amd" ) );
+    }
+
+    public void testProjectsAndAlsoMakeDependents()
+    {
+        logTestStart();
+        
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setProjects( Collections.singletonList( "proj1" ) ).setAlsoMakeDependents( true ), cli );
+
+        assertArgumentsPresentInOrder( cli, "-pl", "proj1", "-amd" );
+    }
+
+    public void testProjectsAndAlsoMakeAndAlsoMakeDependents()
+    {
+        logTestStart();
+        
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setProjects( Collections.singletonList( "proj1" ) ).setAlsoMake( true ).setAlsoMakeDependents( true ), cli );
+
+        assertArgumentsPresentInOrder( cli, "-pl", "proj1", "-am", "-amd" );
+    }
+
+    public void testShouldSetResumeFrom()
+    {
+        logTestStart();
+
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        Commandline cli = new Commandline();
+
+        tcb.setReactorBehavior( newRequest().setResumeFrom( ":module3" ), cli );
+
+        assertArgumentsPresentInOrder( cli, "-rf", ":module3"  );
     }
 
     public void testShouldSetStrictChecksumPolityFlagFromRequest()
@@ -477,7 +546,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setGlobalChecksumPolicy( InvocationRequest.CHECKSUM_POLICY_FAIL ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-C" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-C" ) );
     }
 
     public void testShouldSetLaxChecksumPolicyFlagFromRequest()
@@ -489,7 +558,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setFlags( newRequest().setGlobalChecksumPolicy( InvocationRequest.CHECKSUM_POLICY_WARN ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-c" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-c" ) );
     }
 
     public void testShouldSetFailAtEndFlagFromRequest()
@@ -501,7 +570,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setReactorBehavior( newRequest().setFailureBehavior( InvocationRequest.REACTOR_FAIL_AT_END ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-fae" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-fae" ) );
     }
 
     public void testShouldSetFailNeverFlagFromRequest()
@@ -513,7 +582,7 @@ public class MavenCommandLineBuilderTest
 
         tcb.setReactorBehavior( newRequest().setFailureBehavior( InvocationRequest.REACTOR_FAIL_NEVER ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "-fn" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "-fn" ) );
     }
 
     public void testShouldUseDefaultOfFailFastWhenSpecifiedInRequest()
@@ -525,11 +594,11 @@ public class MavenCommandLineBuilderTest
 
         tcb.setReactorBehavior( newRequest().setFailureBehavior( InvocationRequest.REACTOR_FAIL_FAST ), cli );
 
-        Set banned = new HashSet();
+        Set<String> banned = new HashSet<String>();
         banned.add( "-fae" );
         banned.add( "-fn" );
 
-        assertArgumentsNotPresent( banned, cli );
+        assertArgumentsNotPresent( cli, banned );
     }
 
     public void testShouldSpecifyFileOptionUsingNonStandardPomFileLocation()
@@ -558,11 +627,11 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "non-standard-pom.xml" );
 
-        assertArgumentsPresent( args, cli );
+        assertArgumentsPresent( cli, args );
     }
 
     public void testShouldSpecifyFileOptionUsingNonStandardPomInBasedir()
@@ -591,11 +660,11 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "non-standard-pom.xml" );
 
-        assertArgumentsPresent( args, cli );
+        assertArgumentsPresent( cli, args );
     }
 
     public void testShouldNotSpecifyFileOptionUsingStandardPomFileLocation()
@@ -624,11 +693,11 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "pom.xml" );
 
-        assertArgumentsNotPresent( args, cli );
+        assertArgumentsNotPresent( cli, args );
     }
 
     public void testShouldNotSpecifyFileOptionUsingStandardPomInBasedir()
@@ -657,11 +726,11 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "pom.xml" );
 
-        assertArgumentsNotPresent( args, cli );
+        assertArgumentsNotPresent( cli, args );
     }
 
     public void testShouldUseDefaultPomFileWhenBasedirSpecifiedWithoutPomFileName()
@@ -688,11 +757,11 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "pom.xml" );
 
-        assertArgumentsNotPresent( args, cli );
+        assertArgumentsNotPresent( cli, args );
     }
 
     public void testShouldSpecifyPomFileWhenBasedirSpecifiedWithPomFileName()
@@ -719,14 +788,14 @@ public class MavenCommandLineBuilderTest
 
         assertEquals( projectDir, cli.getWorkingDirectory() );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-f" );
         args.add( "non-standard-pom.xml" );
 
-        assertArgumentsPresent( args, cli );
+        assertArgumentsPresent( cli, args );
     }
 
-    public void testShouldSpecifyCustomSettingsLocationFromRequest()
+    public void testShouldSpecifyCustomUserSettingsLocationFromRequest()
         throws Exception
     {
         logTestStart();
@@ -747,13 +816,68 @@ public class MavenCommandLineBuilderTest
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setSettingsLocation( newRequest().setUserSettingsFile( settingsFile ), cli );
 
-        Set args = new HashSet();
+        Set<String> args = new HashSet<String>();
         args.add( "-s" );
         args.add( settingsFile.getCanonicalPath() );
 
-        assertArgumentsPresent( args, cli );
+        assertArgumentsPresent( cli, args );
+    }
+    
+    public void testShouldSpecifyCustomGlobalSettingsLocationFromRequest()
+        throws Exception
+    {
+        logTestStart();
+
+        File tmpDir = getTempDir();
+        File base = new File( tmpDir, "invoker-tests" );
+
+        toDelete.add( base );
+
+        File projectDir = new File( base, "custom-settings" ).getCanonicalFile();
+
+        projectDir.mkdirs();
+
+        File settingsFile = createDummyFile( projectDir, "settings.xml" );
+
+        Commandline cli = new Commandline();
+
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        tcb.setSettingsLocation( newRequest().setGlobalSettingsFile( settingsFile ), cli );
+
+        Set<String> args = new HashSet<String>();
+        args.add( "-gs" );
+        args.add( settingsFile.getCanonicalPath() );
+
+        assertArgumentsPresent( cli, args );
     }
 
+    public void testShouldSpecifyCustomToolchainsLocationFromRequest()
+        throws Exception
+    {
+        logTestStart();
+
+        File tmpDir = getTempDir();
+        File base = new File( tmpDir, "invoker-tests" );
+
+        toDelete.add( base );
+
+        File projectDir = new File( base, "custom-toolchains" ).getCanonicalFile();
+
+        projectDir.mkdirs();
+
+        File toolchainsFile = createDummyFile( projectDir, "toolchains.xml" );
+
+        Commandline cli = new Commandline();
+
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        tcb.setToolchainsLocation( newRequest().setToolchainsFile( toolchainsFile ), cli );
+
+        Set<String> args = new HashSet<String>();
+        args.add( "-t" );
+        args.add( toolchainsFile.getCanonicalPath() );
+
+        assertArgumentsPresent( cli, args );
+    }
     public void testShouldSpecifyCustomPropertyFromRequest()
         throws IOException
     {
@@ -767,7 +891,7 @@ public class MavenCommandLineBuilderTest
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setProperties( newRequest().setProperties( properties ), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "key=value" }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "key=value" );
     }
 
     public void testShouldSpecifyCustomPropertyWithSpacesInValueFromRequest()
@@ -783,7 +907,7 @@ public class MavenCommandLineBuilderTest
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setProperties( newRequest().setProperties( properties ), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "key=value with spaces" }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "key=value with spaces" );
     }
 
     public void testShouldSpecifyCustomPropertyWithSpacesInKeyFromRequest()
@@ -799,7 +923,7 @@ public class MavenCommandLineBuilderTest
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setProperties( newRequest().setProperties( properties ), cli );
 
-        assertArgumentsPresentInOrder( new String[] { "-D", "key with spaces=value with spaces" }, cli );
+        assertArgumentsPresentInOrder( cli, "-D", "key with spaces=value with spaces" );
     }
 
     public void testShouldSpecifySingleGoalFromRequest()
@@ -809,13 +933,13 @@ public class MavenCommandLineBuilderTest
 
         Commandline cli = new Commandline();
 
-        List goals = new ArrayList();
+        List<String> goals = new ArrayList<String>();
         goals.add( "test" );
 
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setGoals( newRequest().setGoals( goals ), cli );
 
-        assertArgumentsPresent( Collections.singleton( "test" ), cli );
+        assertArgumentsPresent( cli, Collections.singleton( "test" ) );
     }
 
     public void testShouldSpecifyTwoGoalsFromRequest()
@@ -825,17 +949,29 @@ public class MavenCommandLineBuilderTest
 
         Commandline cli = new Commandline();
 
-        List goals = new ArrayList();
+        List<String> goals = new ArrayList<String>();
         goals.add( "test" );
         goals.add( "clean" );
 
         TestCommandLineBuilder tcb = new TestCommandLineBuilder();
         tcb.setGoals( newRequest().setGoals( goals ), cli );
 
-        assertArgumentsPresent( new HashSet( goals ), cli );
-        assertArgumentsPresentInOrder( goals, cli );
+        assertArgumentsPresent( cli, new HashSet<String>( goals ) );
+        assertArgumentsPresentInOrder( cli, goals );
     }
 
+    public void testShouldSpecifyThreadsFromRequest()
+        throws IOException
+    {
+        logTestStart();
+
+        Commandline cli = new Commandline();
+
+        TestCommandLineBuilder tcb = new TestCommandLineBuilder();
+        tcb.setThreads( newRequest().setThreads( "2.0C" ), cli );
+
+        assertArgumentsPresentInOrder( cli, "-T", "2.0C");
+    }
     public void testBuildTypicalMavenInvocationEndToEnd()
         throws Exception
     {
@@ -852,8 +988,8 @@ public class MavenCommandLineBuilderTest
 
         request.setBaseDirectory( projectDir );
 
-        Set expectedArgs = new HashSet();
-        Set bannedArgs = new HashSet();
+        Set<String> expectedArgs = new HashSet<String>();
+        Set<String> bannedArgs = new HashSet<String>();
 
         createDummyFile( projectDir, "pom.xml" );
 
@@ -872,7 +1008,7 @@ public class MavenCommandLineBuilderTest
 
         expectedArgs.add( "-o" );
 
-        List goals = new ArrayList();
+        List<String> goals = new ArrayList<String>();
 
         goals.add( "post-clean" );
         goals.add( "deploy" );
@@ -884,9 +1020,9 @@ public class MavenCommandLineBuilderTest
 
         Commandline commandline = commandLineBuilder.build( request );
 
-        assertArgumentsPresent( expectedArgs, commandline );
-        assertArgumentsNotPresent( bannedArgs, commandline );
-        assertArgumentsPresentInOrder( goals, commandline );
+        assertArgumentsPresent( commandline, expectedArgs );
+        assertArgumentsNotPresent( commandline, bannedArgs );
+        assertArgumentsPresentInOrder( commandline, goals );
 
         File mavenFile;
         if ( Os.isFamily( Os.FAMILY_WINDOWS ) )
@@ -923,7 +1059,7 @@ public class MavenCommandLineBuilderTest
 
         createDummyFile( projectDir, "pom.xml" );
 
-        List goals = new ArrayList();
+        List<String> goals = new ArrayList<String>();
 
         goals.add( "clean" );
         request.setGoals( goals );
@@ -957,7 +1093,7 @@ public class MavenCommandLineBuilderTest
 
         InvocationRequest request = newRequest();
 
-        List profiles = new ArrayList();
+        List<String> profiles = new ArrayList<String>();
         profiles.add( profile1 );
         profiles.add( profile2 );
 
@@ -967,9 +1103,19 @@ public class MavenCommandLineBuilderTest
 
         Commandline commandline = commandLineBuilder.build( request );
 
-        assertArgumentsPresentInOrder( new String[] { "-P", profile1 + "," + profile2 }, commandline );
+        assertArgumentsPresentInOrder( commandline, "-P", profile1 + "," + profile2 );
     }
-
+    
+    public void testMvnCommand() throws Exception
+    {
+        MavenCommandLineBuilder commandLineBuilder = new MavenCommandLineBuilder();
+        File mavenExecutable = new File ( "mvnDebug" );
+        commandLineBuilder.setMavenExecutable( mavenExecutable );
+        File executable = commandLineBuilder.findMavenExecutable();
+        assertTrue( "Expected executable to exist",  executable.exists() );
+        assertTrue( "Expected executable to be absolute", executable.isAbsolute() );
+    }
+    
     public void setUp()
     {
         sysProps = System.getProperties();
@@ -984,10 +1130,8 @@ public class MavenCommandLineBuilderTest
     {
         System.setProperties( sysProps );
 
-        for ( Iterator it = toDelete.iterator(); it.hasNext(); )
+        for ( File file : toDelete )
         {
-            File file = (File) it.next();
-
             if ( file.exists() )
             {
                 if ( file.isDirectory() )
@@ -1011,12 +1155,12 @@ public class MavenCommandLineBuilderTest
         System.out.println( "Starting: " + element.getMethodName() );
     }
 
-    private void assertArgumentsPresentInOrder( String[] expected, Commandline cli )
+    private void assertArgumentsPresentInOrder( Commandline cli, String... expected )
     {
-        assertArgumentsPresentInOrder( Arrays.asList( expected ), cli );
+        assertArgumentsPresentInOrder( cli, Arrays.asList( expected ) );
     }
 
-    private void assertArgumentsPresentInOrder( List expected, Commandline cli )
+    private void assertArgumentsPresentInOrder( Commandline cli, List<String> expected )
     {
         String[] arguments = cli.getArguments();
 
@@ -1034,28 +1178,24 @@ public class MavenCommandLineBuilderTest
             + Arrays.asList( arguments ), expected.size(), expectedCounter );
     }
 
-    private void assertArgumentsPresent( Set requiredArgs, Commandline cli )
+    private void assertArgumentsPresent( Commandline cli, Set<String> requiredArgs )
     {
         String[] argv = cli.getArguments();
-        List args = Arrays.asList( argv );
+        List<String> args = Arrays.asList( argv );
 
-        for ( Iterator it = requiredArgs.iterator(); it.hasNext(); )
+        for ( String arg : requiredArgs )
         {
-            String arg = (String) it.next();
-
             assertTrue( "Command-line argument: \'" + arg + "\' is missing in " + args, args.contains( arg ) );
         }
     }
 
-    private void assertArgumentsNotPresent( Set bannedArgs, Commandline cli )
+    private void assertArgumentsNotPresent( Commandline cli, Set<String> bannedArgs )
     {
         String[] argv = cli.getArguments();
-        List args = Arrays.asList( argv );
+        List<String> args = Arrays.asList( argv );
 
-        for ( Iterator it = bannedArgs.iterator(); it.hasNext(); )
+        for ( String arg : bannedArgs )
         {
-            String arg = (String) it.next();
-
             assertFalse( "Command-line argument: \'" + arg + "\' should not be present.", args.contains( arg ) );
         }
     }
